#LINEAR REGRESSION ADDMISSION
A Python package to predict addmission chances using gre score tofel score and other details
https://github.com/DexDand/linreg-add/blob/master/README.md
##USAGE

main(337,118,4,4.5,4.5,9.65,1)